/*
 UNIVERSITE PARIS 1 (PANTHEON SORBONNE)
 MIAGE - UFR 27
 Cours ISI5 / INF2 - Developpement d'Interface

 */

package ihmexamples.international;

import java.text.DateFormat;
import java.text.NumberFormat;
import java.util.Calendar;
import java.util.Currency;
import java.util.Date;
import java.util.Locale;

/**
 * CEt exemple illustre l'internationalisation par la conversion des valeurs des
 * nombres, monnaies et dates.
 * @author kirsch
 */
public class FormatNumber {

    public static String formatNumber (double nb, Locale loc) {
        NumberFormat fmt = NumberFormat.getNumberInstance(loc);
        String valfmt = fmt.format(nb);
        return (valfmt);
    }

    public static String formatCurrency (double nb, Locale loc){
        NumberFormat fmt = NumberFormat.getCurrencyInstance(loc);
        String valfmt = fmt.format(nb);
        return (valfmt);
    }

    public static String formatPercentual (double nb, Locale loc) {
        NumberFormat fmt = NumberFormat.getPercentInstance(loc);
        String valfmt = fmt.format(nb);
        return (valfmt);
    }

    public static String formatCurrency (double nb, String cur, Locale loc) {
        NumberFormat fmt = NumberFormat.getCurrencyInstance(loc);
        fmt.setCurrency(Currency.getInstance(cur));
        String val = fmt.format(nb);
        return val;
    }

    public static String formatDate(Date dt, int style, Locale loc) {
        DateFormat fmt = DateFormat.getDateInstance(style, loc);
        String date = fmt.format(dt);
        return (date);
    }
  
    /**
     * @param args the command line arguments
     */
    public static void main(String[] args) {
        double val = 1234.56;
        String nb, cur, perc;

        Locale loc = Locale.getDefault();
        nb = formatNumber(val, loc);
        cur = formatCurrency(val,loc);
        perc = formatPercentual(val, loc);

        System.out.println("Locale : " + loc.getDisplayName());
        System.out.println("Number : " + nb);
        System.out.println("Currency : " + cur);
        System.out.println("Perc : " + perc);

        loc = new Locale ("EN", "US");
        nb = formatNumber(val, loc);
        cur = formatCurrency(val,loc);
        perc = formatPercentual(val, loc);

        System.out.println("Locale : " + loc.getDisplayName());
        System.out.println("Number : " + nb);
        System.out.println("Currency : " + cur);
        System.out.println("Perc : " + perc);

        String dollar, euro;
        dollar = formatCurrency(val, "USD", Locale.FRANCE);
        euro = formatCurrency(val, "EUR", Locale.US);
        System.out.println("Dollar in FR : " + dollar);
        System.out.println("Euro in US : " + euro);

        dollar = formatCurrency(val, "USD", Locale.US);
        euro = formatCurrency(val, "EUR", Locale.FRANCE);
        System.out.println("Dollar in US : " + dollar);
        System.out.println("Euro in FR : " + euro);


        String dfull, dlong, dmedium, dshort, ddef;
        Date date = Calendar.getInstance().getTime();

        dfull = formatDate (date, DateFormat.FULL, Locale.FRANCE);
        dlong = formatDate (date, DateFormat.LONG, Locale.FRANCE);
        dmedium = formatDate (date, DateFormat.MEDIUM, Locale.FRANCE);
        dshort = formatDate (date, DateFormat.SHORT, Locale.FRANCE);
        ddef = formatDate (date, DateFormat.DEFAULT, Locale.FRANCE);
        System.out.println ("Date formats (FR) : ");
        System.out.println ("\t Full : " + dfull);
        System.out.println ("\t Long : " + dlong);
        System.out.println ("\t Medium : " + dmedium);
        System.out.println ("\t Short : " + dshort);
        System.out.println ("\t Default : " + ddef);

        dfull = formatDate (date, DateFormat.FULL, Locale.US);
        dlong = formatDate (date, DateFormat.LONG, Locale.US);
        dmedium = formatDate (date, DateFormat.MEDIUM, Locale.US);
        dshort = formatDate (date, DateFormat.SHORT, Locale.US);
        ddef = formatDate (date, DateFormat.DEFAULT, Locale.US);
        System.out.println ("Date formats (US) : ");
        System.out.println ("\t Full : " + dfull);
        System.out.println ("\t Long : " + dlong);
        System.out.println ("\t Medium : " + dmedium);
        System.out.println ("\t Short : " + dshort);
        System.out.println ("\t Default : " + ddef);

    }

}
