/*
 UNIVERSITE PARIS 1 (PANTHEON SORBONNE)
 MIAGE - UFR 27
 Cours ISI5 / INF2 - Developpement d'Interface

 */

package ihmexamples.international;

import java.awt.GridLayout;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;
import java.text.MessageFormat;
import java.util.Arrays;
import java.util.Comparator;
import java.util.Currency;
import java.util.Locale;
import java.util.MissingResourceException;
import java.util.ResourceBundle;
import javax.swing.JComboBox;
import javax.swing.JFrame;
import javax.swing.JLabel;
import javax.swing.JTextField;

/**
 * exemple illustrant l'internationalisation des application.
 * cet exemple permet le parse des nombres et des divises à differents locales
 *
 * @author kirsch
 */
public class ParsingLocaleFrame extends JFrame implements ActionListener {

    private static String RESOURCES_LABEL = "Resources";
    private static String RESOURCES_LABEL_1 = "Label1";
    private static String RESOURCES_LABEL_2 = "Label2";
    private static String RESOURCES_LABEL_3 = "Label3";
    private static String RESOURCES_LABEL_4 = "Label4";
    private static String RESOURCES_TITLE = "Title";

    private static int WIDTH = 300;
    private static int HEIGHT = 200;
    
    private JComboBox localeCombo;
    private JTextField valueText;
    private JLabel convLabel, currConvLabel;
    private String label1, label2, label4, title, patternLabel4;

    private Locale currentLoc;

    private ParsingLocaleController control;

    public ParsingLocaleFrame() {
        currentLoc = Locale.getDefault();
        loadLabels(currentLoc);
        initComponents();
    }

    public ParsingLocaleFrame(ParsingLocaleController control) {
        this();
        this.control = control;
    }

    public void loadLabels (Locale loc) {
         
        try {
          ResourceBundle rb = ResourceBundle.getBundle(RESOURCES_LABEL, loc);
          label1 = rb.getString(RESOURCES_LABEL_1);
          label2 = rb.getString(RESOURCES_LABEL_2);
          patternLabel4 = rb.getString(RESOURCES_LABEL_4);
          title = rb.getString(RESOURCES_TITLE);
        } catch (MissingResourceException mre) {
          label1 = "Locale";
          label2 = "Value";
          title="";
          patternLabel4 = "{0}";
        }

        label4 = MessageFormat.format(patternLabel4,
                Currency.getInstance(currentLoc).getSymbol());
    }

    public void setTextValue (String text) {
        convLabel.setText(text);
    }
    
    public void setTextLabel (Locale loc) {
         label4 = MessageFormat.format(patternLabel4,
                Currency.getInstance(loc).getSymbol());
         currConvLabel.setText(label4);
    }

    public void actionPerformed(ActionEvent e) {
        Locale loc = (Locale) localeCombo.getSelectedItem();
        String text = valueText.getText();
        if (control != null) {
            setTextValue(control.convertNumber(loc, currentLoc, text));
            setTextLabel(loc);
        }
    }


    private Locale[] loadLocales() {
         Locale available[] = Locale.getAvailableLocales().clone();
         Arrays.sort(available, new Comparator<Locale> () {

            public int compare(Locale o1, Locale o2) {
                return o1.getDisplayName().compareTo(o2.getDisplayName());
            }
         });
         return (available);
    }


    private void initComponents() {
        this.setLayout(new GridLayout(3,2));

        JLabel jLabel1 = new JLabel(label1);
        localeCombo = new JComboBox(loadLocales());
        localeCombo.addActionListener(this);
        
        this.add(jLabel1);
        this.add(localeCombo);

        JLabel jLabel2 = new JLabel(label2);
        valueText = new JTextField();

        this.add(jLabel2);
        this.add(valueText);

        currConvLabel = new JLabel(label4);
        convLabel = new JLabel(" ");
        this.add(currConvLabel);
        this.add(convLabel);

        this.setSize(WIDTH, HEIGHT);
        this.setTitle(title);
        this.pack();
    }
    
}
