/*
UNIVERSITE PARIS 1 (PANTHEON SORBONNE)
MIAGE - UFR 27
Cours ISI5 / INF2 - Developpement d'Interface

 */
package ihmexamples.international;

import java.text.NumberFormat;
import java.text.ParseException;
import java.util.Currency;
import java.util.Locale;
import java.util.logging.Level;
import java.util.logging.Logger;

/**
 * stateless class capable de realiser des conversion de nombre et de currency
 * pas de listeners puisque l'interet ici est d'avoir une classe passive, qui
 * fait uniquemente de la convertion, sans informer passivement les paires
 * vue/controle a propos des conversions faites.
 * Ainsi, plusieurs paires vue/controle peuvent utiliser cette classe pour
 * leurs conversions, sans que leur action puisse interferer sur les autres paires
 *
 * @author kirsch
 */
public class ParsingLocaleModel {

    public Locale[] loadLocales() {
        Locale available[] = Locale.getAvailableLocales().clone();
        return (available);
    }

    public String formatCurrency (double nb, Locale loc){
        NumberFormat fmt = NumberFormat.getCurrencyInstance(loc);
        String valfmt = fmt.format(nb);
        return (valfmt);
    }

    public String formatPercentual (double nb, Locale loc) {
        NumberFormat fmt = NumberFormat.getPercentInstance(loc);
        String valfmt = fmt.format(nb);
        return (valfmt);
    }

    public String formatCurrency (double nb, String cur, Locale loc) {
        NumberFormat fmt = NumberFormat.getCurrencyInstance(loc);
        fmt.setCurrency(Currency.getInstance(cur));
        String val = fmt.format(nb);
        return val;
    }

     public String formatNumber (double nb, Locale loc) {
        NumberFormat fmt = NumberFormat.getNumberInstance(loc);
        String valfmt = fmt.format(nb);
        return (valfmt);
    }
    
    public double parseNumber(String text, Locale loc) {
        System.out.println (loc.getDisplayName() + " : " + text);
        double db = 0;
        NumberFormat numberformatter = NumberFormat.getNumberInstance(loc);
        try {
            Number nb = numberformatter.parse(text.trim());
            db = nb.doubleValue();
        } catch (ParseException ex) {
            Logger.getLogger(ParsingLocaleModel.class.getName()).log(Level.SEVERE, null, ex);
        }
        return db;
    }
}
