package ihmexamples.swingmodels;

import java.awt.*;
import java.awt.event.*;
import javax.swing.*;
import javax.swing.tree.*;

/**  Core Java vol. II
This program demonstrates tree editing.
 */
public class JTreeModelDemo {

    public static void main(String[] args) {
        JFrame frame = new TreeEditFrame();
        frame.setDefaultCloseOperation(JFrame.EXIT_ON_CLOSE);
        frame.setVisible(true);
    }
}

/**
A frame with a tree and buttons to edit the tree.
 */
class TreeEditFrame extends JFrame {

    public TreeEditFrame() {
        setTitle("TreeEditTest");
        setSize(WIDTH, HEIGHT);

        // construct tree

        TreeNode root = makeSampleTree();
        model = new DefaultTreeModel(root);
        tree = new JTree(model);
        tree.setEditable(true);

        // add scroll pane with tree to content pane

        JScrollPane scrollPane = new JScrollPane(tree);
        getContentPane().add(scrollPane, BorderLayout.CENTER);

        makeButtons();
    // make button panel

    }

    public TreeNode makeSampleTree() {
        DefaultMutableTreeNode root = new DefaultMutableTreeNode("Moi");
        DefaultMutableTreeNode parent = new DefaultMutableTreeNode("Mamam");
        root.add(parent);
        DefaultMutableTreeNode pere = new DefaultMutableTreeNode("Grand-Mere");
        parent.add(pere);
        DefaultMutableTreeNode fils = new DefaultMutableTreeNode("Grand-Grand-Pere");
        pere.add(fils);
        fils = new DefaultMutableTreeNode("Grand-Grand-Mere");
        pere.add(fils);
        pere = new DefaultMutableTreeNode("Grand-Pere");
        parent.add(pere);
        fils = new DefaultMutableTreeNode("Grand-Grand-Mere");
        pere.add(fils);
        fils = new DefaultMutableTreeNode("Grand-Grand-Pere");
        pere.add(fils);

        parent = new DefaultMutableTreeNode("Papa");
        root.add(parent);
        pere = new DefaultMutableTreeNode("Grand-Mere");
        parent.add(pere);
        fils = new DefaultMutableTreeNode("Grand-Grand-Mere");
        pere.add(fils);
        pere = new DefaultMutableTreeNode("Grand-Pere");
        parent.add(pere);
        fils = new DefaultMutableTreeNode("Grand-Grand-Pere");
        pere.add(fils);

        return root;
    }

    /**
    Makes the buttons to add a sibling, add a child, and
    delete a node.
     */
    public void makeButtons() {
        JPanel panel = new JPanel();

        JButton addChildButton = new JButton("Add Child");
        addChildButton.addActionListener(new ActionListener() {

            public void actionPerformed(ActionEvent event) {
                actionAddButton(event);
            }
        });
        panel.add(addChildButton);

        JButton deleteButton = new JButton("Delete");
        deleteButton.addActionListener(new ActionListener() {

            public void actionPerformed(ActionEvent event) {
                actionRemoveButton(event);
            }
        });
        panel.add(deleteButton);
        getContentPane().add(panel, BorderLayout.SOUTH);
    }

    protected void actionAddButton(ActionEvent event) {
        DefaultMutableTreeNode selectedNode = (DefaultMutableTreeNode) tree.getLastSelectedPathComponent();

        if (selectedNode == null) {
            return;
        }

        DefaultMutableTreeNode newNode = new DefaultMutableTreeNode("New");
        model.insertNodeInto(newNode, selectedNode,
                selectedNode.getChildCount());

        // now display new node

        TreeNode[] nodes = model.getPathToRoot(newNode);
        TreePath path = new TreePath(nodes);
        tree.scrollPathToVisible(path);
    }

    protected void actionRemoveButton(ActionEvent event) {
        DefaultMutableTreeNode selectedNode = (DefaultMutableTreeNode) tree.getLastSelectedPathComponent();

        if (selectedNode != null &&
                selectedNode.getParent() != null) {
            model.removeNodeFromParent(selectedNode);
        }
    }


    private DefaultTreeModel model;
    private JTree tree;
    private static final int WIDTH = 400;
    private static final int HEIGHT = 200;
}
